<?php

namespace Drupal\chathive\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\chathive\ChathiveInterface;

/**
 * Defines the chathive entity type.
 *
 * @ConfigEntityType(
 *   id = "chathive",
 *   label = @Translation("Chathive"),
 *   label_collection = @Translation("Chathives"),
 *   label_singular = @Translation("chathive"),
 *   label_plural = @Translation("chathives"),
 *   label_count = @PluralTranslation(
 *     singular = "@count chathive",
 *     plural = "@count chathives",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\chathive\ChathiveListBuilder",
 *     "form" = {
 *       "default" = "Drupal\chathive\Form\ChathiveForm",
 *       "add" = "Drupal\chathive\Form\ChathiveForm",
 *       "edit" = "Drupal\chathive\Form\ChathiveForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\AdminHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "chathive",
 *   admin_permission = "administer chathive configuration",
 *   links = {
 *     "collection" = "/admin/structure/chathives",
 *     "add-form" = "/admin/structure/chathives/add",
 *     "edit-form" = "/admin/structure/chathives/{chathive}",
 *     "delete-form" = "/admin/structure/chathives/{chathive}/delete"
 *   },
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid",
 *     "pages" = "pages",
 *     "negate" = "negate",
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "description",
 *     "chatbot_id",
 *     "pages",
 *     "negate",
 *   }
 * )
 */
class Chathive extends ConfigEntityBase implements ChathiveInterface {

  /**
   * The chathive ID.
   *
   * @var string
   */
  protected string $id;

  /**
   * The chathive label.
   *
   * @var string
   */
  protected string $label;

  /**
   * The chathive status.
   *
   * @var bool
   */
  protected $status;

  /**
   * The chathive description.
   *
   * @var string
   */
  protected string $description;

  /**
   * The chathive chatbot ID.
   *
   * @var string
   */
  protected $chatbot_id;

  /**
   * Specify pages by using their paths.
   *
   * @var string
   */
  protected string $pages;

  /**
   * If we need to negate the condition.
   *
   * @var bool
   */
  protected bool $negate;

  /**
   * {@inheritdoc}
   */
  public function getChatbotId(): string {
    return trim($this->chatbot_id);
  }

}
