<?php

namespace Drupal\chathive\Form;

use Drupal\Core\Condition\ConditionManager;
use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\system\Plugin\Condition\RequestPath;
use Psr\Container\ContainerInterface;

/**
 * Chathive form.
 *
 * @property \Drupal\chathive\ChathiveInterface $entity
 */
class ChathiveForm extends EntityForm {

  /**
   * The request_path condition plugin.
   *
   * @var \Drupal\system\Plugin\Condition\RequestPath
   */
  protected RequestPath $condition;

  /**
   * Constructs an ChathiveForm object.
   *
   * @param \Drupal\Core\Condition\ConditionManager $condition_manager
   *   The condition manager.
   */
  public function __construct(ConditionManager $condition_manager) {
    $this->condition = $condition_manager->createInstance('request_path');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('plugin.manager.condition')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state): array {

    $form = parent::form($form, $form_state);

    $form['label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#maxlength' => 255,
      '#default_value' => $this->entity->label(),
      '#description' => $this->t('Label for the chathive.'),
      '#required' => TRUE,
    ];

    $form['id'] = [
      '#type' => 'machine_name',
      '#default_value' => $this->entity->id(),
      '#machine_name' => [
        'exists' => '\Drupal\chathive\Entity\Chathive::load',
      ],
      '#disabled' => !$this->entity->isNew(),
    ];

    $form['chatbot_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Chatbot ID'),
      '#default_value' => $this->entity->getChatbotId(),
      '#required' => TRUE,
    ];

    $form['description'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Description'),
      '#default_value' => $this->entity->get('description'),
      '#description' => $this->t('Description of the chathive.'),
    ];

    // Set the default condition configuration.
    $entity = $this->entity;
    if ($entity && $request_path = $entity->get('pages')) {
      $config['pages'] = $request_path;
      $config['negate'] = $entity->get('negate');
      $this->condition->setConfiguration($config);
    }
    // Build the condition configuration form.
    $form += $this->condition->buildConfigurationForm($form, $form_state);

    $form['status'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enabled'),
      '#default_value' => $this->entity->status(),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state): int {
    $result = parent::save($form, $form_state);
    $message_args = ['%label' => $this->entity->label()];
    $message = $result == SAVED_NEW
      ? $this->t('Created new chathive %label.', $message_args)
      : $this->t('Updated chathive %label.', $message_args);
    $this->messenger()->addStatus($message);
    $form_state->setRedirectUrl($this->entity->toUrl('collection'));

    return $result;
  }

}
